pub struct OrphanModule {
pub path: String,
pub symbols: usize,
}Expand description
Orphan module (never imported).
Fields
path: Stringsymbols: usizeTrait Implementations
Sourceimpl Debug for OrphanModule
impl Debug for OrphanModule
Sourceimpl JsonSchema for OrphanModule
impl JsonSchema for OrphanModule
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OrphanModule
impl RefUnwindSafe for OrphanModule
impl Send for OrphanModule
impl Sync for OrphanModule
impl Unpin for OrphanModule
impl UnsafeUnpin for OrphanModule
impl UnwindSafe for OrphanModule